@@ -26,17 +26,23 @@ class MDns:
                 ipaddr = str(ipaddress.IPv4Address(addr))
                 self._root.add_device_by_ip(ipaddr, "mDns")
 
-    def __init__(self, root):
+    def update_service(self, zconf, type, name):
+        """ Update a service in the collection. """
+        self.add_service(zconf, type, name)
+
+    def __init__(self, root, zeroconf = None):
         self._root = root
+        self._common_zeroconf = zeroconf
         self._zeroconf = None
         self._browser = None
 
     def start(self):
-        self._zeroconf = zeroconf = Zeroconf()
+        self._zeroconf = zeroconf = self._common_zeroconf or Zeroconf()
         self._browser = \
             ServiceBrowser(zeroconf, "_http._tcp.local.", self)
 
     def close(self):
         if self._zeroconf:
-            self._zeroconf.close()
+            if not self._common_zeroconf:
+                self._zeroconf.close()
             self._zeroconf = None
